@@ -31,10 +31,10 @@ combined.
 4. `refinery.units`: writing custom units, add command-line arguments, and how
    to use refinery units within Python code.
 """
-__version__ = '0.4.35'
+__version__ = '0.4.36'
 __distribution__ = 'binary-refinery'
 
-from typing import Dict, List, Type
+from typing import Dict, List, Optional, Type
 from importlib import resources
 from datetime import datetime
 
@@ -106,17 +106,8 @@ class _cache:
             self.reloading = False
             self.save()
 
-    def _resolve(self, name, retry=0):
-        if retry > 2:
-            raise AttributeError(name)
-        elif retry >= 2:
-            now = datetime.utcnow()
-            delta = now - self.last_reload
-            if delta.total_seconds() < 10:
-                raise AttributeError(name)
-            self.last_reload = now
-            self.reload()
-        elif retry >= 1:
+    def resolve(self, name) -> Optional[Unit]:
+        if not self.loaded:
             self.load()
         try:
             module_path = self.units[name]
@@ -125,10 +116,7 @@ class _cache:
             self.cache[name] = entry
             return entry
         except (KeyError, ModuleNotFoundError):
-            return self._resolve(name, retry + 1)
-
-    def __getitem__(self, name):
-        return self._resolve(name)
+            return None
 
 
 @_singleton
@@ -158,7 +146,7 @@ class __pdoc__(dict):
         self['Unit'] = False
         self['Arg'] = False
         for name in _cache.units:
-            unit = _cache[name]
+            unit = _cache.resolve(name)
             for base in unit.mro():
                 try:
                     abstractmethods: List[str] = base.__abstractmethods__
@@ -191,14 +179,15 @@ __all__ = sorted(_cache.units, key=lambda x: x.lower()) + [
 
 
 def __getattr__(name):
-    return _cache[name]
+    unit = _cache.resolve(name)
+    if unit is None:
+        raise AttributeError(name)
+    return unit
 
 
 def __dir__():
     return __all__
 
 
-def load(name):
-    if _cache.loaded:
-        return _cache.cache.get(name)
-    return _cache[name]
+def load(name) -> Optional[Unit]:
+    return _cache.resolve(name)
