@@ -14,6 +14,7 @@ There are several units that are specifically designed to store meta variables:
   sub-pipeline inside a meta variable; more on this later.
 - The `refinery.cm` unit is a catch-all helper to generate common metadata such as size, frame
   index, hashes, entropy, etcetera.
+- The unit `refinery.wm` can be used to remove all metadata from a chunk.
 - The `refinery.struct` parses structured data from the beginning of a chunk into meta variables.
 - You can use named capture groups in regular expressions when using the `refinery.rex` unit, and
   these matches will be stored under their name as a meta variable in each output chunk.
@@ -54,7 +55,7 @@ that can contain meta variables. For example, the following command will print a
 of the current directory with human-readable file sizes, entropy in percent, and the md5 hash of
 each file:
 
-    ef ** [| cm size | sha256 -t | cfmt {size!r} {entropy!r} {md5} {path} ]]
+    ef ** [| cfmt {size!r} {entropy!r} {md5} {path} ]]
 
 Another example would be the following command, which dumps the base64 encoded buffer of length at
 least 200 from the input to incrementally numbered files:
@@ -111,12 +112,23 @@ import codecs
 
 from io import StringIO
 from urllib.parse import quote_from_bytes, unquote_to_bytes
-from typing import Callable, Dict, Iterable, Optional, ByteString, Union
+from typing import Callable, Dict, Iterable, Optional, ByteString, Union, TYPE_CHECKING
 
 from refinery.lib.structures import MemoryFile
 from refinery.lib.tools import isbuffer, entropy, index_of_coincidence
 
 
+if TYPE_CHECKING:
+    from typing import Protocol
+
+    class _Derivation(Protocol):
+        costly: bool
+        name: str
+
+        def __call__(self, object: LazyMetaOracle) -> Union[str, int, float]:
+            ...
+
+
 class CustomStringRepresentation(abc.ABC):
     """
     This abstract class defines an interface for wrapper classes used in `refinery.lib.meta.LazyMetaOracleFactory`.
@@ -313,15 +325,17 @@ class _LazyMetaMeta(type):
         derivations: dict = namespace['DERIVATION_MAP']
         for obj in namespace.values():
             try:
+                obj: _Derivation
                 derivations[obj.name] = obj
             except AttributeError:
                 pass
         return type.__new__(cls, name, bases, namespace)
 
 
-def _derivation(name):
-    def decorator(method):
+def _derivation(name, costly: bool = False) -> Callable[[_Derivation], _Derivation]:
+    def decorator(method: _Derivation) -> _Derivation:
         method.name = name
+        method.costly = costly
         return method
     return decorator
 
@@ -338,7 +352,7 @@ class LazyMetaOracle(dict, metaclass=_LazyMetaMeta):
         'size'    : SizeInt,
     }
 
-    DERIVATION_MAP: Dict[str, Callable[[LazyMetaOracle], Union[str, int, float]]] = {}
+    DERIVATION_MAP: Dict[str, _Derivation] = {}
     """
     A dictionary mapping the names of common properties to anonymous functions that compute their
     corresponding value on a chunk of binary input data.
@@ -346,11 +360,13 @@ class LazyMetaOracle(dict, metaclass=_LazyMetaMeta):
 
     ghost: bool
     chunk: ByteString
+    cache: Dict[str, Union[str, int, float]]
 
     def __init__(self, chunk: ByteString, *args, **kwargs):
         super().__init__(*args, **kwargs)
         self.ghost = False
         self.chunk = chunk
+        self.cache = {}
         self.fix()
 
     def update(self, *args, **kwargs):
@@ -598,13 +614,20 @@ class LazyMetaOracle(dict, metaclass=_LazyMetaMeta):
             return self[key]
 
     def __missing__(self, key):
+        try:
+            return self.cache[key]
+        except KeyError:
+            pass
         deduction = self.DERIVATION_MAP.get(key)
         if deduction is None:
             raise KeyError(F'The meta variable {key} is unknown.')
         try:
-            return self.setdefault(key, deduction(self))
+            value = deduction(self)
         except _NoDerivationAvailable:
             raise KeyError(F'unable to derive the {key} property here, you have to use the cm unit.')
+        else:
+            self.cache[key] = value
+            return value
 
     def discard(self, key):
         try:
@@ -631,11 +654,11 @@ class LazyMetaOracle(dict, metaclass=_LazyMetaMeta):
     def _derive_size(self):
         return SizeInt(len(self.chunk))
 
-    @_derivation('entropy')
+    @_derivation('entropy', True)
     def _derive_entropy(self):
         return Percentage(entropy(self.chunk))
 
-    @_derivation('ic')
+    @_derivation('ic', True)
     def _derive_ic(self):
         return Percentage(index_of_coincidence(self.chunk))
 
@@ -644,22 +667,22 @@ class LazyMetaOracle(dict, metaclass=_LazyMetaMeta):
         import zlib
         return ByteStringWrapper((zlib.crc32(self.chunk) & 0xFFFFFFFF).to_bytes(4, 'big').hex())
 
-    @_derivation('sha1')
+    @_derivation('sha1', True)
     def _derive_sha1(self):
         import hashlib
         return ByteStringWrapper(hashlib.sha1(self.chunk).hexdigest())
 
-    @_derivation('sha256')
+    @_derivation('sha256', True)
     def _derive_sha256(self):
         import hashlib
         return ByteStringWrapper(hashlib.sha256(self.chunk).hexdigest())
 
-    @_derivation('sha512')
+    @_derivation('sha512', True)
     def _derive_sha512(self):
         import hashlib
         return ByteStringWrapper(hashlib.sha512(self.chunk).hexdigest())
 
-    @_derivation('md5')
+    @_derivation('md5', True)
     def _derive_md5(self):
         import hashlib
         return ByteStringWrapper(hashlib.md5(self.chunk).hexdigest())
